package com.landray.kmss.plugin.util;

import java.io.IOException;
import org.apache.commons.httpclient.Cookie;
import org.apache.commons.httpclient.DefaultHttpMethodRetryHandler;
import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpException;
import org.apache.commons.httpclient.HttpMethod;
import org.apache.commons.httpclient.methods.GetMethod;
import org.apache.commons.httpclient.methods.PostMethod;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;

public class HttpClientUtil {

   private static Logger logger = LogManager.getLogger(HttpClientUtil.class);
   private static int ONE_DAY = 86400;
   private static final String SESSION_KEY = "com.landray.kmss.HttpClient";


   public static HttpClient createClient() {
      return new HttpClient();
   }

   public static void addCookieToHttpClient(HttpClient client, String domain, String cookieName, String cookieValue) {
      client.getParams().setCookiePolicy("rfc2109");
      Cookie cookie = new Cookie(domain, cookieName, cookieValue, "/", ONE_DAY, false);
      client.getState().addCookie(cookie);
   }

   public static GetMethod createGetMethod(String url) {
      GetMethod method = new GetMethod(url);
      method.setRequestHeader("Connection", "close");
      method.getParams().setParameter("http.method.retry-handler", new DefaultHttpMethodRetryHandler());
      return method;
   }

   public static PostMethod createPostMethod(String url) {
      PostMethod method = new PostMethod(url);
      method.setRequestHeader("Connection", "close");
      method.getParams().setParameter("http.method.retry-handler", new DefaultHttpMethodRetryHandler());
      return method;
   }

   public static String formatBase64Value(String value) {
      if(value == null) {
         return null;
      } else {
         int n = value.length() % 8;
         String result = value;

         for(int i = 0; i < n; ++i) {
            result = result + "=";
         }

         return result;
      }
   }

   public static String getDomainByUrl(String url) {
      int index = url.indexOf("://");

      String domain;
      for(domain = url.substring(index + 3); domain.startsWith("/"); domain = domain.substring(1)) {
         ;
      }

      index = domain.indexOf(47);
      if(index > -1) {
         domain = domain.substring(0, index);
      }

      return domain;
   }

   public static String getDataByHttpClient(HttpClient client, HttpMethod method) throws HttpException, IOException {
      String var5;
      try {
         int statusCode = client.executeMethod(method);
         if(statusCode != 200) {
            logger.error("HttpClient GET方法执行失败：  " + method.getStatusLine());
         }

         byte[] responseBody = method.getResponseBody();
         String result = new String(responseBody, "UTF-8");
         if(result != null) {
            result = result.trim();
         }

         var5 = result;
      } finally {
         method.releaseConnection();
      }

      return var5;
   }

   public static void main(String[] args) throws Exception {
      String url = "http://ekptest.yutong.com/ekp/sys/common/dataxml.jsp?s_bean=sysHomePortletDialog";
      String cookieValue = "0e8e2f9171eb11da2beb804be61143fbe692d5c3c1aec77de659e0d1adf00cbf8008412091b83febee671870ef289e7dd5b788d68f9f0363c907816ac8126ee4ce9b0973caa2eab6044c654f2d89169c4e499674fa848a0a1f3b4504be1b16bdec85d16da81ac3e9d4ac30f0743a18a38751b880c3c694c9f417e8ae9c27fca4";
      HttpClient client = createClient();

      for(int i = 0; i < 1; ++i) {
         long t = System.currentTimeMillis();
         addCookieToHttpClient(client, getDomainByUrl(url), "LRToken", cookieValue);
         GetMethod method = createGetMethod(url);
         System.out.println(getDataByHttpClient(client, method));
         System.out.println("============ " + (System.currentTimeMillis() - t) + " ============");
      }

   }

}
